@@ -1,4 +1,5 @@
 from microconventions.sep_conventions import SepConventions
+import os
 
 
 class MiscConventions(SepConventions):
@@ -54,4 +55,31 @@ class MiscConventions(SepConventions):
     def cdf_name(self, name, delay=None):
         return self.CDF + name if delay == None else self.CDF + str(delay) + self.SEP + name
 
+    def performance_name(self, write_key):
+        return self.PERFORMANCE + write_key + '.json'
 
+    def balance_name(self, write_key):
+        return self.BALANCE + write_key + '.json'
+
+    def transactions_name(self, write_key=None, name=None, delay=None ):
+        """ Convention for names of transactions records """
+        delay     = None if delay is None else str(delay)
+        key_stem  = None if write_key is None else os.path.splitext(write_key)[0]
+        name_stem = None if name is None else os.path.splitext(name)[0]
+        tail = self.SEP.join( [ s for s in [key_stem,delay,name_stem] if s is not None ])
+        return self.TRANSACTIONS + tail + '.json'
+
+    def delayed_name(self, name, delay):
+        return self.DELAYED + str(delay) + self.SEP + name
+
+    def messages_name(self, name):
+        return self.MESSAGES + name
+
+    def confirms_name(self, write_key):
+        return self.CONFIRMS + write_key + '.json'
+
+    def errors_name(self, write_key):
+        return self.ERRORS + write_key + '.json'
+
+    def warnings_name(self, write_key):
+        return self.WARNINGS + write_key + '.json'
